@@ -12,11 +12,7 @@ use base qw(Exporter);
 use autodie qw(open close);
 use Carp;
 
-use Crypt::NSS::X509::Certificate;
-use Crypt::NSS::X509::CertList;
-use Crypt::NSS::X509::CRL;
-
-$VERSION = '0.01_2';
+$VERSION = '0.01_1';
 
 @EXPORT_OK = qw(
 );
@@ -95,3 +91,71 @@ END {
   __PACKAGE__->__cleanup;
 }
 
+package Crypt::NSS::X509::CRL;
+
+sub new_from_pem {
+	my $class = shift;
+	my $pem = shift;
+
+	$pem =~ s/-+BEGIN.*CRL-+// or die("Could not find crl start");
+	$pem =~ s/-+END.*CRL-+// or die("Could not find crl end");
+
+	my $der = MIME::Base64::decode($pem);
+	if ( length($der) < 1 ) {
+		die("Could not decode crl");
+	}
+
+	return $class->new_from_der($der, @_);
+}
+
+package Crypt::NSS::X509::CertList;
+
+sub new_from_rootlist {
+	my ($class, $filename) = @_;
+
+	my $certlist = Crypt::NSS::X509::CertList->new();
+
+	my $pem;
+
+	open (my $fh, "<", $filename);
+	while ( my $line = <$fh> ) {
+		if ( $line =~ /--BEGIN CERTIFICATE--/ .. $line =~ /--END CERTIFICATE--/ ) {
+
+			$pem .= $line;
+
+			if ( $line =~ /--END CERTIFICATE--/ ) {
+				#say "|$pem|";
+				my $cert = Crypt::NSS::X509::Certificate->new_from_pem($pem);
+				$pem = "";
+				$certlist->add($cert);
+			}
+		}
+	}
+
+	close($fh);
+
+	return $certlist;
+}
+
+package Crypt::NSS::X509::Certificate;
+use MIME::Base64 ();
+
+sub new_from_pem {
+	my $class = shift;
+	my $pem = shift;
+
+	$pem =~ s/-----BEGIN CERTIFICATE-----// or die("Did not found certificate start");
+	$pem =~ s/-----END CERTIFICATE-----// or die ("Did not found certificate end");
+
+	my $der = MIME::Base64::decode($pem);
+	if ( length($der) < 1 ) {
+		die("Could not decode certificate");
+	}
+
+	return $class->new($der, @_);
+}
+
+1;
+
+__END__
+
